AppBuilder typedef

AppBuilder = Widget Function(BuildContext context, Widget child)

Function signature for building the app wrapper around use cases.

The AppBuilder receives a BuildContext and the child widget (use case) and should return a widget that wraps the child with the appropriate app-level widgets like MaterialApp, CupertinoApp, or WidgetsApp.

Implementation

typedef AppBuilder = Widget Function(BuildContext context, Widget child);