Config class

Constructors

Config({String initialRoute = '/', List<Component<Widget, StoryArgs<Widget>>> components = const [], AppBuilder appBuilder = materialAppBuilder, Widget home = const DefaultHomePage(), List<Addon>? addons, List<Integration>? integrations, ThemeData? lightTheme, ThemeData? darkTheme, ThemeMode themeMode = ThemeMode.system, Widget? header, ScrollBehavior? scrollBehavior = const MaterialScrollBehavior(), ScenarioConfig scenarioConfig = const ScenarioConfig(), List<DocBlock> docsBuilder()? = defaultDocsBuilder})
const

Properties

addons List<Addon>?
The list of add-ons for your Widget library
final
appBuilder AppBuilder
A wrapper builder method for all Components.
final
components List<Component<Widget, StoryArgs<Widget>>>
The list of Components that will be displayed in Widgetbook.
final
darkTheme ThemeData?
The custom theme for the Widgetbook interface when using dark mode.
final
docsBuilder List<DocBlock> Function()?
A builder function that returns the list of DocBlocks to be displayed in the documentation panel.
final
hashCode int
The hash code for this object.
no setterinherited
An optional widget to display at the top of the navigation panel. This can be used for branding or additional information.
final
home Widget
The home widget is a widget that is shown on startup when no use-case is selected. This widget does not inherit from the appBuilder or the addons; meaning that if Theme.of(context) is called inside this widget, then it will use Widgetbook's lightTheme or darkTheme and not the Theme from the appBuilder or the ThemeAddon.
final
initialRoute String
The initial route for that will be used on first startup.
final
integrations List<Integration>?
The list of integrations for your Widget library.
final
lightTheme ThemeData?
The custom theme for the Widgetbook interface when using light mode.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scenarioConfig ScenarioConfig
Global ScenarioConfig applied to every Story of every Component.
final
scrollBehavior ScrollBehavior?
The ScrollBehavior to be applied to the Widgetbook application itself.
final
themeMode ThemeMode
The theme mode to be applied to the Widgetbook application.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited