EnumArg<T extends Enum> class

Inheritance

Constructors

EnumArg(T value, {String? name, required List<T> values, LabelBuilder<T>? labelBuilder = enumLabelBuilder, SingleArgStyle style = const DropdownSingleArgStyle()})

Properties

$generatedName String
latefinalinherited
description String?
The description of the composable group.
finalinherited
field Field<T>
no setterinherited
fields List<Field>
A list of Fields that belong to this composable group.
no setterinherited
groupName String
The name of the query group param.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
initialValue ↔ T
The initial value of the composable group.
latefinalinherited
isNullable bool
Whether this composable group is nullable.
no setterinherited
labelBuilder → LabelBuilder<T>?
finalinherited
name String
The display name of the composable group.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style SingleArgStyle
finalinherited
value ↔ T
getter/setter pairinherited
values List<T>
finalinherited

Methods

buildFields(BuildContext context) Widget
Converts the fields into a Widget that will be rendered in the settings side panel.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paramOf<TField>(String name, TField value) String
Encodes the value of the Field with name to a query parameter using the Field.toParam.
inherited
slugify(String name) String
Converts the name to a slugified version that can be used in query parameters.
inherited
toQueryGroup() QueryGroup?
inherited
toString() String
A string representation of this object.
inherited
update(BuildContext context, T newValue) → void
inherited
valueFromQueryGroup(QueryGroup? group) → T
Converts a query group to a value of type T. group can be null if there is no query parameter for this group.
inherited
valueOf<TField>(String name, QueryGroup group) → TField
Decodes the value of the Field with name from the query group using the Field.toValue.
inherited
valueToQueryGroup(T value) QueryGroup
Converts a value of type T to a query group.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

enumLabelBuilder(Enum value) String