toWidget abstract method
Converts this field into a Widget that can be used in the settings panel.
value is the current value of the field from the query group,
or initialValue in case the field is not found in the group or couldn't
be decoded.
Implementation
Widget toWidget(BuildContext context, String groupName, T value);