IntInputField class final

A Field that builds TextFormField for int values.

Inheritance

Constructors

IntInputField({required String name, int? initialValue = 0, @Deprecated('Fields should not be aware of their context') void onChanged(BuildContext context, int? value)?})
Creates a new instance of IntInputField.

Properties

formatters List<TextInputFormatter>
The list of input formatters to apply to the text input.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initialValue int
The default value when no value is specified.
finalinherited
name String
The unique identifier for this field within its group.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toParam String Function(int value)
Encoder for converting value of type T to a query parameter.
finalinherited
toValue int? Function(String param)
Decoders for converting a query parameter to a value of type T. Can return null if the parameter is invalid.
finalinherited

Methods

build(BuildContext context, String groupName) Widget
Builds the current field into a Widget using toWidget.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWidget(BuildContext context, String groupName, int value) Widget
Converts this field into a Widget that can be used in the settings panel.
inherited
updateField(BuildContext context, String groupName, int value) → void
Updates the field value in the WidgetbookState and synchronizes it with the URL query parameters.
inherited
valueFrom(QueryGroup? group) int
Extracts the value from group, fallback to initialValue if field is not found or cannot be decoded.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited