labelBuilder property
LabelBuilder<T>
labelBuilder
final
The function to build the label for each value in the segmented button.
Implementation
final LabelBuilder<T> labelBuilder;
The function to build the label for each value in the segmented button.
final LabelBuilder<T> labelBuilder;