Meta class

Metadata for generating code for a single constructor of a widget.

The constructor must be a constructor tear-off of the widget, e.g. Meta(MyButton.new) or Meta(MyButton.icon). Generated types for named constructors are prefixed with the PascalCase constructor name, e.g. _IconStory and _IconArgs for MyButton.icon.

By default, args are derived from the widget constructor's parameters. Provide argsType with a constructor tear-off of a custom args class to derive them from that constructor instead, e.g. Meta(MyButton.new, argsType: MyButtonInput.new). Stories then require a builder that maps the custom args to the widget.

Meta variables must be declared as const.

Constructors

Meta(Function constructor, {Function? argsType})
const

Properties

argsType Function?
final
constructor Function
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited