Mode<T> class abstract

A Mode represents a specific configuration or state of an Addon. It holds a value of type T that defines the current setting of the addon.

Implementers

Constructors

Mode(T value, Addon<T> addon)
const

Properties

addon Addon<T>
The associated addon for this mode. Used to build the story, and to convert to/from query parameters.
final
formattedValue String
The name of this value to be used for displaying purposes.
no setter
groupName String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

build(BuildContext context, Widget child) Widget
Builds the Addon with the mode's value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryGroup() QueryGroup
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited