ScenarioDefinition class
Defines a template for generating scenarios.
- Implementers
Constructors
-
ScenarioDefinition({required String name, required List<
Mode> modes, ScenarioStrategy strategy = ScenarioStrategy.perScenario, ModesMerger mergeModes = defaultMergeModes})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mergeModes → ModesMerger
-
A function to merge the modes defined in the story and the ones
defined in this Scenario or ScenarioDefinition.
final
-
modes
→ List<
Mode> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → ScenarioStrategy
-
How this definition is expanded into Scenarios for each Story.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited