ViewportMode class

Inheritance

Constructors

ViewportMode(ViewportData value)

Properties

addon Addon<ViewportData>
The associated addon for this mode. Used to build the story, and to convert to/from query parameters.
finalinherited
formattedValue String
The name of this value to be used for displaying purposes.
no setteroverride
groupName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ViewportData
finalinherited

Methods

build(BuildContext context, Widget child) Widget
Builds the Addon with the mode's value.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryGroup() QueryGroup
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited