Viewports class abstract

A collection of all predefined viewports across platforms.

Constructors

Viewports()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const List<ViewportData>
A list of all predefined viewports across platforms. This includes iOS, Android, macOS, Windows, and Linux viewports.
none → const NoneViewport
Represents no viewport.