WindowsViewports class abstract

A collection of predefined Windows viewports.

Constructors

WindowsViewports()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const List<ViewportData>
A list of all Windows viewports.
desktop → const ViewportData
Represents a viewport for a typical Windows desktop environment.