AndroidViewports class abstract
A collection of predefined Android viewports.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const List<
ViewportData> - A list of all Android viewports.
- largeTablet → const ViewportData
- Represents a viewport for a large Android tablet.
- mediumTablet → const ViewportData
- Represents a viewport for a medium Android tablet.
- onePlus8Pro → const ViewportData
- Represents a viewport for the OnePlus 8 Pro device.
-
phones
→ const List<
ViewportData> - A list of all Android phones.
- samsungGalaxyA50 → const ViewportData
- Represents a viewport for the Samsung Galaxy A50 device.
- samsungGalaxyNote20 → const ViewportData
- Represents a viewport for the Samsung Galaxy Note 20 device.
- samsungGalaxyNote20Ultra → const ViewportData
- Represents a viewport for the Samsung Galaxy Note 20 Ultra device.
- samsungGalaxyS20 → const ViewportData
- Represents a viewport for the Samsung Galaxy S20 device.
- smallTablet → const ViewportData
- Represents a viewport for a small Android tablet.
- sonyXperia1II → const ViewportData
- Represents a viewport for the Sony Xperia 1 II device.
-
tablets
→ const List<
ViewportData> - A list of all Android tablets.